componenttools.extend_left_in_parent_of_component
=================================================

.. autofunction:: abjad.tools.componenttools.extend_left_in_parent_of_component.extend_left_in_parent_of_component
